# Table of Contents

- [production-and-sandbox-workspaces](<./production-and-sandbox-workspaces.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Production and Sandbox Workspaces](<./Production-and-Sandbox-Workspaces.md>)
  - [Introduction](<./Production-and-Sandbox-Workspaces/Introduction.md>)
  - [Difference Between a Production and a Sandbox Workspace](<./Production-and-Sandbox-Workspaces/Difference-Between-a-Production-and-a-Sandbox-Workspace.md>)
  - [Production Workspace Best Practices](<./Production-and-Sandbox-Workspaces/Production-Workspace-Best-Practices.md>)
  - [Sandbox Workspace Best Practices](<./Production-and-Sandbox-Workspaces/Sandbox-Workspace-Best-Practices.md>)
  - [Was this page helpful?](<./Production-and-Sandbox-Workspaces/Was-this-page-helpful.md>)
